summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrake.ApplicationServices/Converters/EnumToDescConverter.cs
diff options
context:
space:
mode:
Diffstat (limited to 'win/CS/HandBrake.ApplicationServices/Converters/EnumToDescConverter.cs')
-rw-r--r--win/CS/HandBrake.ApplicationServices/Converters/EnumToDescConverter.cs19
1 files changed, 11 insertions, 8 deletions
diff --git a/win/CS/HandBrake.ApplicationServices/Converters/EnumToDescConverter.cs b/win/CS/HandBrake.ApplicationServices/Converters/EnumToDescConverter.cs
index d66f27a7e..a9cc5410b 100644
--- a/win/CS/HandBrake.ApplicationServices/Converters/EnumToDescConverter.cs
+++ b/win/CS/HandBrake.ApplicationServices/Converters/EnumToDescConverter.cs
@@ -1,8 +1,11 @@
-/* EnumToDescConveter.cs $
- This file is part of the HandBrake source code.
- Homepage: <http://handbrake.fr>.
- It may be used under the terms of the GNU General Public License. */
-
+// --------------------------------------------------------------------------------------------------------------------
+// <copyright file="EnumToDescConverter.cs" company="HandBrake Project (http://handbrake.fr)">
+// This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
+// </copyright>
+// <summary>
+// Enum to Description Converter
+// </summary>
+// --------------------------------------------------------------------------------------------------------------------
namespace HandBrake.ApplicationServices.Converters
{
@@ -14,15 +17,15 @@ namespace HandBrake.ApplicationServices.Converters
/// <summary>
/// Enum to Description Converter
/// </summary>
- public class EnumToDescConveter : EnumConverter
+ public class EnumToDescConverter : EnumConverter
{
/// <summary>
/// Initializes a new instance of the <see cref="EnumToDescConveter"/> class.
/// </summary>
/// <param name="type">
/// The type.
/// </param>
- public EnumToDescConveter(Type type)
+ public EnumToDescConverter(Type type)
: base(type)
{
}
@@ -14,15 +17,15 @@ namespace HandBrake.ApplicationServices.Converters
{
/// <summary>
- /// Initializes a new instance of the <see cref="EnumToDescConveter"/> class.
+ /// Initializes a new instance of the <see cref="EnumToDescConverter"/> class.
/// </summary>
/// <param name="type">